/**
 * eobjects.org MetaModel
 * Copyright (C) 2010 eobjects.org
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.eobjects.metamodel.jdbc.dialects;

import org.eobjects.metamodel.jdbc.JdbcDataContext;
import org.eobjects.metamodel.query.Query;
import org.eobjects.metamodel.query.SelectItem;
import org.eobjects.metamodel.schema.ColumnType;

/**
 * Query rewriter for IBM DB2
 */
public class DB2QueryRewriter extends DefaultQueryRewriter implements IQueryRewriter {

	public DB2QueryRewriter(JdbcDataContext dataContext) {
		super(dataContext);
	}

	@Override
	public String escapeQuotes(String filterItemOperand) {
		return filterItemOperand.replaceAll("\\'", "\\\\'");
	}

	/**
	 * DB2 expects the fully qualified column name, including schema, in select
	 * items.
	 */
	@Override
	protected String rewriteSelectItem(Query query, SelectItem item) {
		return item.toSql(true);
	}

	@Override
	public String rewriteColumnType(ColumnType columnType) {
		switch (columnType) {
		case BOOLEAN:
		case BIT:
			return "SMALLINT";
		default:
			return super.rewriteColumnType(columnType);
		}
	}
}